/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the NeXTstation non-ADB keyboard
 * for the co-Xist 3.0 X server.  By Eric Benson <eb@NeXT.com>.
 */

static const KeyCode NeXT_codes [] = {
  /* Row 0 */
  81, 82, 83, 84, 85, 88, 87, 86, 38, 39, 40, 37, 36, 35,
  46, 47, 48, 45,
  /* Row 1 */
  73, 74, 75, 76, 77, 80, 79, 78, 14, 15, 16, 13, 12, 11,
  41, 42, 43, 44,
  /* Row 2 */
  126, 65, 66, 67, 68, 69, 72, 71, 70, 53, 52, 51, 50,
  26, 32, 27, 29,
  /* Row 3 */
  127, 57, 58, 59, 60, 61, 63, 62, 54, 55, 56, 131,
  30,
  25, 31, 28, 21,
  /* Row 4 */
  128, 129, 64, 130, 132,
  17, 23, 24,
  19, 20
};
